@@ -35,7 +35,9 @@ def get_ellipse_color(img,x,y,xax,yax,angle):
     x2 = round(x + max/2)
     y1 = round(y - max/2)
     y2 = round(y + max/2)
-
+    if x1 < 0: x1 = 0
+    if y1 < 0: y1 = 0
+    
     if xax < 1 or yax < 1:
         return [ (get_lab_color_class(0,0,0) , 1.0) ]#black
 
@@ -49,7 +51,7 @@ def get_ellipse_color(img,x,y,xax,yax,angle):
     if rows == 0 or columns == 0:
         print("cannot create image with dimension", rows,columns,x,y,xax,yax)
         return [ (get_lab_color_class(0,0,0) , 1.0) ]#black
-        
+
     mask = np.zeros([rows , columns,3],dtype=np.uint8)
 
     # create a white filled ellipse
